@@ -12,16 +12,29 @@ from pytestqt.wait_signal import (
     CallbackCalledTwiceError,
 )
 
+flaky_on_macos = pytest.mark.xfail(
+    sys.platform == "darwin", run=False, reason="Flaky on macOS: #313"
+)
 
-def test_signal_blocker_exception(qtbot):
+
+@pytest.mark.parametrize(
+    "method, signal, timeout",
+    [
+        ("waitSignal", None, None),
+        ("waitSignal", None, 1000),
+        ("waitSignals", [], None),
+        ("waitSignals", [], 1000),
+        ("waitSignals", None, None),
+        ("waitSignals", None, 1000),
+    ],
+)
+def test_signal_blocker_none(qtbot, method, signal, timeout):
     """
-    Make sure waitSignal without signals and timeout doesn't hang, but raises
-    ValueError instead.
+    Make sure waitSignal without signals isn't supported anymore.
     """
+    meth = getattr(qtbot, method)
     with pytest.raises(ValueError):
-        qtbot.waitSignal(None, None).wait()
-    with pytest.raises(ValueError):
-        qtbot.waitSignals([], None).wait()
+        meth(signal, timeout=timeout).wait()
 
 
 def explicit_wait(qtbot, signal, timeout, multiple, raising, should_raise):
@@ -29,7 +42,7 @@ def explicit_wait(qtbot, signal, timeout, multiple, raising, should_raise):
     Explicit wait for the signal using blocker API.
     """
     func = qtbot.waitSignals if multiple else qtbot.waitSignal
-    blocker = func(signal, timeout, raising=raising)
+    blocker = func(signal, timeout=timeout, raising=raising)
     assert not blocker.signal_triggered
     if should_raise:
         with pytest.raises(qtbot.TimeoutError):
@@ -46,10 +59,10 @@ def context_manager_wait(qtbot, signal, timeout, multiple, raising, should_raise
     func = qtbot.waitSignals if multiple else qtbot.waitSignal
     if should_raise:
         with pytest.raises(qtbot.TimeoutError):
-            with func(signal, timeout, raising=raising) as blocker:
+            with func(signal, timeout=timeout, raising=raising) as blocker:
                 pass
     else:
-        with func(signal, timeout, raising=raising) as blocker:
+        with func(signal, timeout=timeout, raising=raising) as blocker:
             pass
     return blocker
 
@@ -81,6 +94,7 @@ def build_signal_tests_variants(params):
         ]
     ),
 )
+@flaky_on_macos
 def test_signal_triggered(
     qtbot,
     timer,
@@ -104,7 +118,7 @@ def test_signal_triggered(
     blocker = wait_function(
         qtbot,
         signaller.signal,
-        timeout,
+        timeout=timeout,
         raising=raising,
         should_raise=should_raise,
         multiple=False,
@@ -134,16 +148,13 @@ def test_zero_timeout(qtbot, timer, delayed, signaller):
 @pytest.mark.parametrize(
     "configval, raises", [("false", False), ("true", True), (None, True)]
 )
-@pytest.mark.parametrize("configkey", ["qt_wait_signal_raising", "qt_default_raising"])
-def test_raising(qtbot, testdir, configkey, configval, raises):
+def test_raising(qtbot, testdir, configval, raises):
     if configval is not None:
         testdir.makeini(
-            """
+            f"""
             [pytest]
-            {} = {}
-        """.format(
-                configkey, configval
-            )
+            qt_default_raising = {configval}
+        """
         )
 
     testdir.makepyfile(
@@ -162,11 +173,7 @@ def test_raising(qtbot, testdir, configkey, configval, raises):
     """
     )
 
-    if configkey == "qt_wait_signal_raising" and configval is not None:
-        with pytest.warns(DeprecationWarning):
-            res = testdir.runpytest()
-    else:
-        res = testdir.runpytest()
+    res = testdir.runpytest()
 
     if raises:
         res.stdout.fnmatch_lines(["*1 failed*"])
@@ -174,16 +181,12 @@ def test_raising(qtbot, testdir, configkey, configval, raises):
         res.stdout.fnmatch_lines(["*1 passed*"])
 
 
-@pytest.mark.filterwarnings("ignore:qt_wait_signal_raising is deprecated")
-@pytest.mark.parametrize("configkey", ["qt_wait_signal_raising", "qt_default_raising"])
-def test_raising_by_default_overridden(qtbot, testdir, configkey):
+def test_raising_by_default_overridden(qtbot, testdir):
     testdir.makeini(
         """
         [pytest]
-        {} = false
-    """.format(
-            configkey
-        )
+        qt_default_raising = false
+    """
     )
 
     testdir.makepyfile(
@@ -228,6 +231,7 @@ def test_raising_by_default_overridden(qtbot, testdir, configkey):
         ]
     ),
 )
+@flaky_on_macos
 def test_signal_triggered_multiple(
     qtbot,
     timer,
@@ -253,7 +257,7 @@ def test_signal_triggered_multiple(
     blocker = wait_function(
         qtbot,
         [signaller.signal, signaller.signal_2],
-        timeout,
+        timeout=timeout,
         multiple=True,
         raising=raising,
         should_raise=should_raise,
@@ -369,14 +373,7 @@ def test_wait_signals_invalid_strict_parameter(qtbot, signaller):
 
 
 def test_destroyed(qtbot):
-    """Test that waitSignal works with the destroyed signal (#82).
-
-    For some reason, this crashes PySide although it seems perfectly fine code.
-    """
-    if qt_api.pytest_qt_api.startswith("pyside"):
-        pytest.skip("test crashes PySide and PySide2")
-
-    import sip
+    """Test that waitSignal works with the destroyed signal (#82)."""
 
     class Obj(qt_api.QtCore.QObject):
         pass
@@ -385,7 +382,7 @@ def test_destroyed(qtbot):
     with qtbot.waitSignal(obj.destroyed):
         obj.deleteLater()
 
-    assert sip.isdeleted(obj)
+    assert qt_api.isdeleted(obj)
 
 
 class TestArgs:
@@ -397,9 +394,9 @@ class TestArgs:
             signaller.signal_args.emit("test", 123)
         assert blocker.args == ["test", 123]
 
-    def test_timeout(self, qtbot):
+    def test_timeout(self, qtbot, signaller):
         """If there's a timeout, the args attribute is None."""
-        with qtbot.waitSignal(timeout=100, raising=False) as blocker:
+        with qtbot.waitSignal(signaller.signal, timeout=100, raising=False) as blocker:
             pass
         assert blocker.args is None
 
@@ -428,7 +425,7 @@ def test_signal_identity(signaller):
     """
     Tests that the identity of signals can be determined correctly, using str(signal).
 
-    Some Qt frameworks, such as PyQt4 or PyQt5, have the following issue:
+    PyQt5 has the following issue:
     x = signaller.signal
     y = signaller.signal
     x == y  # is False
@@ -883,9 +880,9 @@ class TestAllArgs:
 def get_mixed_signals_with_guaranteed_name(signaller):
     """
     Returns a list of signals with the guarantee that the signals have names (i.e. the names are
-    manually provided in case of using PySide, where the signal names cannot be determined at run-time).
+    manually provided in case of using PySide2, where the signal names cannot be determined at run-time).
     """
-    if qt_api.pytest_qt_api.startswith("pyside"):
+    if qt_api.is_pyside:
         signals = [
             (signaller.signal, "signal()"),
             (signaller.signal_args, "signal_args(QString,int)"),
@@ -920,9 +917,9 @@ class TestAllSignalsAndArgs:
         Tests that all_signals_and_args is empty even though expected signals are emitted, but signal names aren't
         available.
         """
-        if qt_api.pytest_qt_api != "pyside":
+        if qt_api.pytest_qt_api != "pyside2":
             pytest.skip(
-                "test only makes sense for PySide, whose signals don't contain a name!"
+                "test only makes sense for PySide2, whose signals don't contain a name!"
             )
 
         with qtbot.waitSignals(
@@ -981,9 +978,6 @@ class TestAllSignalsAndArgs:
         ]
 
 
-PY_2 = sys.version_info[0] == 2
-
-
 class TestWaitSignalTimeoutErrorMessage:
     """Tests that the messages of TimeoutError are formatted correctly, for waitSignal() calls."""
 
@@ -992,7 +986,7 @@ class TestWaitSignalTimeoutErrorMessage:
         In a situation where a signal without args is expected but not emitted, tests that the TimeoutError
         message contains the name of the signal (without arguments).
         """
-        if qt_api.pytest_qt_api.startswith("pyside"):
+        if qt_api.is_pyside:
             signal = (signaller.signal, "signal()")
         else:
             signal = signaller.signal
@@ -1005,50 +999,13 @@ class TestWaitSignalTimeoutErrorMessage:
         ex_msg = TestWaitSignalsTimeoutErrorMessage.get_exception_message(excinfo)
         assert ex_msg == "Signal signal() not emitted after 200 ms"
 
-    def test_unable_to_get_callback_name(self, qtbot, signaller):
-        """
-        Test that for complicated callbacks which aren't callables, but e.g. double-wrapped partials, the test code
-        is sometimes unable to determine the name of the callback.
-        Note that this behavior changes with Python 3.5, where a functools.partial() is smart enough to detect wrapped
-        calls.
-        """
-        if sys.version_info >= (3, 5):
-            pytest.skip(
-                "Only on Python 3.4 and lower double-wrapped functools.partial callbacks are a problem"
-            )
-
-        if qt_api.pytest_qt_api.startswith("pyside"):
-            signal = (signaller.signal_single_arg, "signal_single_arg(int)")
-        else:
-            signal = signaller.signal_single_arg
-
-        def callback(int_param, unused_param1, unused_param2):
-            return int_param == 1337
-
-        wrapped_callback = functools.partial(callback, unused_param2=1)
-        double_wrapped_callback = functools.partial(wrapped_callback, unused_param1=1)
-
-        with pytest.raises(TimeoutError) as excinfo:
-            with qtbot.waitSignal(
-                signal=signal,
-                timeout=200,
-                raising=True,
-                check_params_cb=double_wrapped_callback,
-            ):
-                signaller.signal_single_arg.emit(1)
-        ex_msg = TestWaitSignalsTimeoutErrorMessage.get_exception_message(excinfo)
-        assert ex_msg == (
-            "Signal signal_single_arg(int) emitted with parameters [1] within 200 ms, "
-            "but did not satisfy the  callback"
-        )
-
     def test_with_single_arg(self, qtbot, signaller):
         """
         In a situation where a signal with one argument is expected but the emitted instances have values that are
         rejected by a callback, tests that the TimeoutError message contains the name of the signal and the
         list of non-accepted arguments.
         """
-        if qt_api.pytest_qt_api.startswith("pyside"):
+        if qt_api.is_pyside:
             signal = (signaller.signal_single_arg, "signal_single_arg(int)")
         else:
             signal = signaller.signal_single_arg
@@ -1074,7 +1031,7 @@ class TestWaitSignalTimeoutErrorMessage:
         rejected by a callback, tests that the TimeoutError message contains the name of the signal and the
         list of tuples of the non-accepted arguments.
         """
-        if qt_api.pytest_qt_api.startswith("pyside"):
+        if qt_api.is_pyside:
             signal = (signaller.signal_args, "signal_args(QString,int)")
         else:
             signal = signaller.signal_args
@@ -1090,12 +1047,6 @@ class TestWaitSignalTimeoutErrorMessage:
                 signaller.signal_args.emit("2", 2)
         ex_msg = TestWaitSignalsTimeoutErrorMessage.get_exception_message(excinfo)
         parameters = "[('1', 1), ('2', 2)]"
-        if PY_2:
-            parameters = "[(u'1', 1), (u'2', 2)]"
-            if qt_api.pytest_qt_api == "pyqt4":
-                parameters = (
-                    "[(PyQt4.QtCore.QString(u'1'), 1), (PyQt4.QtCore.QString(u'2'), 2)]"
-                )
         assert ex_msg == (
             "Signal signal_args(QString,int) emitted with parameters {} "
             "within 200 ms, but did not satisfy the arg_validator callback"
@@ -1174,10 +1125,6 @@ class TestWaitSignalsTimeoutErrorMessage:
                 signaller.signal_args.emit("1", 1)
         ex_msg = TestWaitSignalsTimeoutErrorMessage.get_exception_message(excinfo)
         signal_args = "'1', 1"
-        if PY_2:
-            signal_args = "u'1', 1"
-            if qt_api.pytest_qt_api == "pyqt4":
-                signal_args = "PyQt4.QtCore.QString(u'1'), 1"
         assert ex_msg == (
             "Emitted signals: [signal_args({})]. Missing: "
             "[signal(), signal_args(QString,int) (callback: my_callback_2)]"
@@ -1219,10 +1166,6 @@ class TestWaitSignalsTimeoutErrorMessage:
                 signaller.signal_args.emit("1", 1)
         ex_msg = TestWaitSignalsTimeoutErrorMessage.get_exception_message(excinfo)
         signal_args = "'1', 1"
-        if PY_2:
-            signal_args = "u'1', 1"
-            if qt_api.pytest_qt_api == "pyqt4":
-                signal_args = "PyQt4.QtCore.QString(u'1'), 1"
         assert ex_msg == (
             "Emitted signals: [signal_args({})]. Missing: "
             "[signal(), signal_args(QString,int), signal_args(QString,int)]"
@@ -1246,10 +1189,6 @@ class TestWaitSignalsTimeoutErrorMessage:
                 signaller.signal.emit()
         ex_msg = TestWaitSignalsTimeoutErrorMessage.get_exception_message(excinfo)
         signal_args = "'1', 1"
-        if PY_2:
-            signal_args = "u'1', 1"
-            if qt_api.pytest_qt_api == "pyqt4":
-                signal_args = "PyQt4.QtCore.QString(u'1'), 1"
         assert ex_msg == (
             "Signal order violated! Expected signal() as 1st signal, "
             "but received signal_args({}) instead. Emitted signals: [signal_args({}), signal]. "
@@ -1258,11 +1197,11 @@ class TestWaitSignalsTimeoutErrorMessage:
 
     def test_degenerate_error_msg(self, qtbot, signaller):
         """
-        Tests that the TimeoutError message is degenerate when using PySide signals for which no name is provided
+        Tests that the TimeoutError message is degenerate when using PySide2 signals for which no name is provided
         by the user. This degenerate messages doesn't contain the signals' names, and includes a hint to the user how
         to fix the situation.
         """
-        if not qt_api.pytest_qt_api.startswith("pyside"):
+        if qt_api.pytest_qt_api != "pyside2":
             pytest.skip(
                 "test only makes sense for PySide, whose signals don't contain a name!"
             )
